@@ -76,19 +76,3 @@ xfree(void *ptr)
   fprintf(stderr,"DEBUG: freed %p\n",ptr);
 #endif /* DEBUG */
 }
-
-
-/* strdup() wrapper */
-char *
-xstrdup(const char *str)
-{
-  char *res;
-  res=strdup(str);
-  if (res==NULL)
-  {
-    if (!quiet)
-      fprintf(stderr,_("Error allocating memory!\n"));
-    exit(1);
-  }
-  return res;
-}
