@@ -43,8 +43,4 @@ void *xrealloc(void *ptr,size_t size);
 void xfree(void *ptr);
 
 
-/* strdup() wrapper */
-char *xstrdup(const char *s);
-
-
 #endif /* _ALLOC_H */
