@@ -1,7 +1,7 @@
 /*
    rl - Select a random line from stdin or file.
 
-   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Arthur de Jong
+   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Arthur de Jong
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ display_usage(FILE *fp)
 static void
 display_tryhelp(FILE *fp)
 {
-  fprintf(fp,_("Try `%s --help' for more information.\n"),program_name);
+  fprintf(fp,_("Try '%s --help' for more information.\n"),program_name);
 }
 
 
@@ -111,16 +111,16 @@ display_version(FILE *fp)
 {
   fprintf(fp,"rl %s\n",VERSION);
   fprintf(fp,_("Written by Arthur de Jong.\n\n"));
-  fprintf(fp,_("Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Arthur de Jong.\n"
+  fprintf(fp,_("Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Arthur de Jong.\n"
                "This is free software; see the source for copying conditions.  There is NO\n"
                "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"));
 }
 
 
 /* read the whole file and pick out count random lines and dump to out
-   all arguments are assumed to be reasonable values 
+   all arguments are assumed to be reasonable values
    any line has an equal chance of getting picked
-   and lines may be selected multiple times 
+   and lines may be selected multiple times
    lines are delimited by delim */
 static void
 rl_withreplace(FILE *in,FILE *out,int count,char delim,int print_linenumbers)
@@ -185,7 +185,7 @@ rl_withreplace(FILE *in,FILE *out,int count,char delim,int print_linenumbers)
 
 
 /* read the whole file and pick out count random lines and dump to out
-   all arguments are assumed to be reasonable values 
+   all arguments are assumed to be reasonable values
    (maybe a better functionname, my English is not that good )
    any line can only be picked once
    lines are delimited by delim */
@@ -283,7 +283,7 @@ rl_withoutreplace(FILE *in,FILE *out,int count,char delim,int print_linenumbers)
 }
 
 
-/* read file and randomize and output all lines 
+/* read file and randomize and output all lines
    this is done in a way that any line will only be returned once */
 static void
 rl_randomizefile(FILE *in,FILE *out,char delim,int print_linenumbers)
@@ -379,11 +379,11 @@ main(int argc,char **argv)
   int print_linenumbers=0; /* wether to output line numbers */
 
   program_name=argv[0];
-  
+
   /* parse command-line options */
   while ((c=getopt_long(argc,argv,OPTION_STRING,
                         long_options,(int *)NULL))!=-1)
-  { 
+  {
     /* find out which option was specified */
     switch (c)
     {
@@ -395,7 +395,7 @@ main(int argc,char **argv)
       exit(0);
     case 'c': /* -c, --count=N */
       count=strtol(optarg,&endptr,0);
-      if ( (optarg[0]=='\0') || (endptr[0]!='\0') || 
+      if ( (optarg[0]=='\0') || (endptr[0]!='\0') ||
            (count<1) )
       {
         if (!quiet)
@@ -451,7 +451,7 @@ main(int argc,char **argv)
 
   /* intialize the random-number generator */
   randomize();
-  
+
   /* open the output if specified */
   if ( (outputf!=NULL) && (strcmp(outputf,"-")!=0) )
   {
